==> sisu_5.6.0.orig.tar.xz: sisu-5.6.0/lib/sisu/v5/src_share.rb <==
# encoding: utf-8
=begin

 * Name: SiSU

 * Description: a framework for document structuring, publishing and search

 * Author: Ralph Amissah

 * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
   2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Ralph Amissah,
   All Rights Reserved.

 * License: GPL 3 or later:

   SiSU, a framework for document structuring, publishing and search

   Copyright (C) Ralph Amissah

   This program is free software: you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the Free
   Software Foundation, either version 3 of the License, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful, but WITHOUT
   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
   FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
   more details.

   You should have received a copy of the GNU General Public License along with
   this program. If not, see <http://www.gnu.org/licenses/>.

   If you have Internet connection, the latest version of the GPL should be
   available at these locations:
   <http://www.fsf.org/licensing/licenses/gpl.html>
   <http://www.gnu.org/licenses/gpl.html>

   <http://www.sisudoc.org/sisu/en/manifest/gpl.fsf.html>

 * SiSU uses:
   * Standard SiSU markup syntax,
   * Standard SiSU meta-markup syntax, and the
   * Standard SiSU object citation numbering and system

 * Hompages:
   <http://www.jus.uio.no/sisu>
   <http://www.sisudoc.org>

 * Download:
   <http://www.sisudoc.org/sisu/en/SiSU/download.html>

 * Git
   <http://sources.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
   <http://sources.sisudoc.org/?p=code/sisu.git;a=blob;f=lib/sisu/v5/src_share.rb;hb=HEAD>

 * Ralph Amissah
   <ralph@amissah.com>
   <ralph.amissah@gmail.com>

 ** Description: share sisu source markup file, copy it to output directory!

=end
module SiSU_Markup
  require_relative 'src_shared'                         # src_shared.rb
    include SiSU_Source
  require_relative 'se'                                 # se.rb
    include SiSU_Env
  class Source < SiSU_Source::SiSUpodSource
    def initialize(opt,build=nil,place=nil)
      super(opt,build,place)
      @opt=opt
    end
    def read
      unless @opt.act[:quiet][:set]==:on
        (@opt.act[:verbose][:set]==:on \
        || @opt.act[:verbose_plus][:set]==:on \
        || @opt.act[:maintenance][:set]==:on) \
        ? SiSU_Screen::Ansi.new(
            @opt.act[:color_state][:set],
            'Share document markup text source',
            @opt.fns
          ).cyan_hi_blue
        : SiSU_Screen::Ansi.new(
            @opt.act[:color_state][:set],
            'Share document markup text source',
            @opt.fns
          ).cyan_title_hi
      end
      if FileTest.directory?(@path_pod[:fnb])
        FileUtils::mkdir_p(@file.output_path.src.dir) \
          unless FileTest.directory?(@file.output_path.src.dir)
        v=(@opt.act[:maintenance][:set]==:on) \
        ? 'v' : ''
        system(%{
          rsync -a#{v} #{@path_pod[:fnb]} #{@file.output_path.sisupod.dir}
          chbk=`pwd`
          cd #{@file.output_path.sisupod.dir}
          for I in `find -type d` ; do chmod 755 $I ; done
          for I in `find -type f` ; do chmod 644 $I ; done
          cd ${chbk}
        })
      else
        if (@opt.act[:verbose][:set]==:on \
        || @opt.act[:verbose_plus][:set]==:on \
        || @opt.act[:maintenance][:set]==:on)
          SiSU_Screen::Ansi.new(
            '',
            "#{@opt.fno} not available"
          ).blue_tab
        end
      end
    end
  end
end
__END__

==> sisu_5.6.7.orig.tar.xz: sisu-5.6.7/lib/sisu/v5/src_share.rb <==
# encoding: utf-8
=begin

 * Name: SiSU

 * Description: a framework for document structuring, publishing and search

 * Author: Ralph Amissah

 * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
   2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Ralph Amissah,
   All Rights Reserved.

 * License: GPL 3 or later:

   SiSU, a framework for document structuring, publishing and search

   Copyright (C) Ralph Amissah

   This program is free software: you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the Free
   Software Foundation, either version 3 of the License, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful, but WITHOUT
   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
   FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
   more details.

   You should have received a copy of the GNU General Public License along with
   this program. If not, see <http://www.gnu.org/licenses/>.

   If you have Internet connection, the latest version of the GPL should be
   available at these locations:
   <http://www.fsf.org/licensing/licenses/gpl.html>
   <http://www.gnu.org/licenses/gpl.html>

   <http://www.sisudoc.org/sisu/en/manifest/gpl.fsf.html>

 * SiSU uses:
   * Standard SiSU markup syntax,
   * Standard SiSU meta-markup syntax, and the
   * Standard SiSU object citation numbering and system

 * Hompages:
   <http://www.jus.uio.no/sisu>
   <http://www.sisudoc.org>

 * Download:
   <http://www.sisudoc.org/sisu/en/SiSU/download.html>

 * Git
   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
   <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=blob;f=lib/sisu/v5/src_share.rb;hb=HEAD>

 * Ralph Amissah
   <ralph@amissah.com>
   <ralph.amissah@gmail.com>

 ** Description: share sisu source markup file, copy it to output directory!

=end
module SiSU_Markup
  require_relative 'src_shared'                         # src_shared.rb
    include SiSU_Source
  require_relative 'se'                                 # se.rb
    include SiSU_Env
  class Source < SiSU_Source::SiSUpodSource
    def initialize(opt,build=nil,place=nil)
      super(opt,build,place)
      @opt=opt
    end
    def read
      unless @opt.act[:quiet][:set]==:on
        (@opt.act[:verbose][:set]==:on \
        || @opt.act[:verbose_plus][:set]==:on \
        || @opt.act[:maintenance][:set]==:on) \
        ? SiSU_Screen::Ansi.new(
            @opt.act[:color_state][:set],
            'Share document markup text source',
            @opt.fns
          ).cyan_hi_blue
        : SiSU_Screen::Ansi.new(
            @opt.act[:color_state][:set],
            'Share document markup text source',
            @opt.fns
          ).cyan_title_hi
      end
      if FileTest.directory?(@path_pod[:fnb])
        FileUtils::mkdir_p(@file.output_path.src.dir) \
          unless FileTest.directory?(@file.output_path.src.dir)
        v=(@opt.act[:maintenance][:set]==:on) \
        ? 'v' : ''
        system(%{
          rsync -a#{v} #{@path_pod[:fnb]} #{@file.output_path.sisupod.dir}
          chbk=`pwd`
          cd #{@file.output_path.sisupod.dir}
          for I in `find -type d` ; do chmod 755 $I ; done
          for I in `find -type f` ; do chmod 644 $I ; done
          cd ${chbk}
        })
      else
        if (@opt.act[:verbose][:set]==:on \
        || @opt.act[:verbose_plus][:set]==:on \
        || @opt.act[:maintenance][:set]==:on)
          SiSU_Screen::Ansi.new(
            '',
            "#{@opt.fno} not available"
          ).blue_tab
        end
      end
    end
  end
end
__END__
